from setuptools import setup, find_packages

setup(
    name="search2o",  # Replace with your desired package name
    version="0.0.1",
    author="Ram Venkat",
    author_email="info@search2o.com",
    description="Just a placeholder",
    packages=find_packages(),
    python_requires=">=3.13",
)
